using UnityEngine;
using System.Collections;

public class PlayerScript : MonoBehaviour {

	private BoxCollider2D boxColl;
	private SpriteRenderer spriteRenderer;
	private WallScript.Pos currPos;
	private float xRight;
	private float xLeft;

	private Vector3 orPos;
	private bool inputEnabled = false;
	private ParticleSystem deathParticles;

	void Awake() {
		orPos = transform.position;
		boxColl = GetComponent<BoxCollider2D>();
		spriteRenderer = GetComponent<SpriteRenderer>();
		deathParticles = GetComponentInChildren<ParticleSystem>();
	}

	void Start() {
		GameManager.instance.StartGame += StartGame;
		GameManager.instance.GameOver+= GameOver;
	}

	void StartGame() {
		transform.position = orPos;
		inputEnabled = true;
		boxColl.enabled = true;
		spriteRenderer.enabled = true;
		deathParticles.Clear();
		xRight = Camera.main.ScreenToWorldPoint(new Vector3(Screen.width, 0, 0)).x - boxColl.bounds.extents.x * 2;
		xLeft = Camera.main.ScreenToWorldPoint(Vector3.zero).x + boxColl.bounds.extents.x * 2;
		currPos = (Random.Range(0, 2) == 0) ? WallScript.Pos.Right : WallScript.Pos.Left;
		switch (currPos) {
			case WallScript.Pos.Right:
				StartCoroutine(LerpToPosition(xRight));
				break;
			case WallScript.Pos.Left:
				StartCoroutine(LerpToPosition(xLeft));
				break;
		}
	}
	
	void GameOver() {
		inputEnabled = false;
		boxColl.enabled = false;
		spriteRenderer.enabled = false;
		deathParticles.Emit(50);
	}

	void Update () {
		if (Input.GetButtonDown("Fire1") && inputEnabled) {
			switch (currPos) {
				case WallScript.Pos.Right:
					StopAllCoroutines();
					StartCoroutine(LerpToPosition(xLeft));
					currPos = WallScript.Pos.Left;
					break;
				case WallScript.Pos.Left:
					StopAllCoroutines();
					StartCoroutine(LerpToPosition(xRight));
					currPos = WallScript.Pos.Right;
					break;
			}
		}
	}

	void OnTriggerEnter2D(Collider2D other) {
		if (other.tag == "Spike") {
			GameManager.instance.ChangeGameMode(GameMode.GameOver);
		}
	}

	IEnumerator LerpToPosition(float xPos) {
		Vector3 orPos = transform.position;
		float tParam = 0;
		while (tParam < 1) {
			tParam += Time.deltaTime * 3;
			transform.position = new Vector3(Mathf.Lerp(orPos.x, xPos, tParam), orPos.y, orPos.z);
			yield return null;
		}
	}
}
