using UnityEngine;
using System.Collections;

public class WallScript : MonoBehaviour {

	public enum Pos {
		Right, Left
	}

	public Pos wallPos;
	public GameObject spikePrefab;
	public int size = 6;
	public float minSecs = 1;
	public float maxSecs = 4;

	private GameObject[] spikes;
	private int spikeCounter = 0;

	void Start() {
		SetPosition();
		GameManager.instance.StartGame += StartGame;
		GameManager.instance.GameOver += GameOver;
	}

	void StartGame () {
		if (spikes == null) spikes = new GameObject[size];
		else {
			foreach (GameObject obj in spikes) Destroy(obj);
			spikeCounter = 0;
		}
		StartCoroutine(SpawnSpikes());
	}

	void SetPosition() {
		float xPos;
		switch (wallPos) {
			case Pos.Right:
				xPos = Camera.main.ScreenToWorldPoint(new Vector3(Screen.width, 0, 0)).x;
				break;
			case Pos.Left:
				xPos = Camera.main.ScreenToWorldPoint(Vector3.zero).x;
				break;
			default:
				xPos = 0;
				break;
		}
		transform.position = new Vector3(xPos, transform.position.y, 0);
	}

	void GameOver() {
		StopAllCoroutines();
	}

	IEnumerator SpawnSpikes() {
		Vector3 spikePos = (wallPos == Pos.Right) ? new Vector3(transform.position.x - 0.7f, transform.position.y, 0) : new Vector3(transform.position.x + 0.72f, transform.position.y, 0);
		while (true) {
			yield return new WaitForSeconds(Random.Range(minSecs, maxSecs));
			if (spikeCounter < size) {
				spikes[spikeCounter] = (GameObject)Instantiate(spikePrefab, spikePos, spikePrefab.transform.rotation);
				if (wallPos == Pos.Left) spikes[spikeCounter].GetComponent<SpriteRenderer>().flipY = true;
				spikeCounter++;
			} else {
				spikes[(spikeCounter++) % size].transform.position = spikePos;
			}
			yield return null;
		}
	}
	
}
